:orphan:

.. _gallery:

Example Gallery
================

This section contains a collection of examples demonstrating how to use the package ``pysdic`` for various applications. 




.. raw:: html

    <div class="sphx-glr-thumbnails">

.. thumbnail-parent-div-open

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip=" This example demonstrates a simple workflow for creating, manipulating, and visualizing a mesh using the pysdic library.">

.. only:: html

  .. image:: /_gallery/images/thumb/sphx_glr_example_mesh_simple_workflow_thumb.png
    :alt:

  :doc:`/_gallery/example_mesh_simple_workflow`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Simple mesh workflow</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example demonstrates a simple workflow for creating, manipulating, and visualizing a point cloud using the pysdic library.">

.. only:: html

  .. image:: /_gallery/images/thumb/sphx_glr_example_pointcloud_simple_workflow_thumb.png
    :alt:

  :doc:`/_gallery/example_pointcloud_simple_workflow`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Simple point cloud workflow</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example demonstrates how to use the Bouguer law and Ward&#x27;s BRDF model from the pysdic library to render photometric properties on a cylindrical mesh.">

.. only:: html

  .. image:: /_gallery/images/thumb/sphx_glr_example_photometric_rendering_on_cylinder_thumb.png
    :alt:

  :doc:`/_gallery/example_photometric_rendering_on_cylinder`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Rendering Photometric Properties on a Cylinder</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip=" This example demonstrates a simple workflow for computing the vertices and elements adjacency matrices for a mesh using the pysdic library.">

.. only:: html

  .. image:: /_gallery/images/thumb/sphx_glr_example_adjacency_mesh_computation_thumb.png
    :alt:

  :doc:`/_gallery/example_adjacency_mesh_computation`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Adjacency matrix computation for meshes</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example demonstrates how to project a mesh on a camera and compute the corresponding gray levels values and XYZ jacobian using the pysdic library.">

.. only:: html

  .. image:: /_gallery/images/thumb/sphx_glr_example_project_a_mesh_on_a_camera_thumb.png
    :alt:

  :doc:`/_gallery/example_project_a_mesh_on_a_camera`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Project a Mesh on a Camera and obtains the corresponding pixel coordinates (and jacobians of the projection)</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example demonstrates how to use the pysdic.compute_property_interpolation (or pysdic.assemble_property_interpolation) and pysdic.compute_property_projection (or pysdic.assemble_property_projection) functions from the pysdic library to interpolate and project properties at integration points within a mesh.     ">

.. only:: html

  .. image:: /_gallery/images/thumb/sphx_glr_example_integration_points_interpolation_thumb.png
    :alt:

  :doc:`/_gallery/example_integration_points_interpolation`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Heightmap interpolation and projection at integration points</div>
    </div>


.. thumbnail-parent-div-close

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /_gallery/example_mesh_simple_workflow
   /_gallery/example_pointcloud_simple_workflow
   /_gallery/example_photometric_rendering_on_cylinder
   /_gallery/example_adjacency_mesh_computation
   /_gallery/example_project_a_mesh_on_a_camera
   /_gallery/example_integration_points_interpolation


.. only:: html

  .. container:: sphx-glr-footer sphx-glr-footer-gallery

    .. container:: sphx-glr-download sphx-glr-download-python

      :download:`Download all examples in Python source code: _gallery_python.zip </_gallery/_gallery_python.zip>`

    .. container:: sphx-glr-download sphx-glr-download-jupyter

      :download:`Download all examples in Jupyter notebooks: _gallery_jupyter.zip </_gallery/_gallery_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
